@@ -25,7 +25,6 @@
 #include <Lum/Label.h>
 #include <Lum/LED.h>
 #include <Lum/Panel.h>
-#include <Lum/Space.h>
 #include <Lum/String.h>
 #include <Lum/Text.h>
 
@@ -69,8 +68,6 @@ public:
 
   void PreInit()
   {
-    Lum::Button        *button;
-    Lum::ButtonRow     *bRow;
     Lum::DirNameSelect *dirSel;
     Lum::Label         *label;
     Lum::Panel         *panel;
@@ -87,21 +84,9 @@ public:
     label->AddLabel(L"Image path:",dirSel);
 
     panel->Add(label);
-
-    panel->Add(new Lum::VSpace());
-
-    bRow=new Lum::ButtonRow();
-    bRow->SetFlex(true,false);
-
-    button=new Lum::Button();
-    button->SetFlex(true,true);
-    button->SetModel(GetClosedAction());
-    button->SetType(Lum::Button::typeDefault);
-    button->SetText(L"_Close");
-
-    bRow->Add(button);
-
-    panel->Add(bRow);
+    panel->AddSpace();
+    panel->Add(Lum::ButtonRow::Create(true,false)
+               ->Add(Lum::Button::Create(L"_Close",GetClosedAction(),Lum::Button::typeDefault,true,true)));
 
     SetMain(panel);
 
@@ -230,81 +215,39 @@ public:
 
   void PreInit()
   {
-    Lum::AspectRatio   *aspect;
-    Lum::Button        *button;
     Lum::LED           *led;
     Lum::Panel         *vpanel,*vpanel2,*hpanel;
-    Lum::String        *string;
-    Lum::Text          *text;
 
-    vpanel=new Lum::VPanel();
-    vpanel->SetFlex(true,true);
+    vpanel=Lum::VPanel::Create(true,true);
 
-    hpanel=new Lum::HPanel();
-    hpanel->SetFlex(true,true);
-
-    aspect=new Lum::AspectRatio();
-    aspect->SetFlex(true,true);
-    aspect->SetAspectRatio(640,480);
+    hpanel=Lum::HPanel::Create(true,true);
 
     control->SetFlex(true,true);
-    aspect->SetObject(control);
 
-    hpanel->Add(aspect);
+    hpanel->Add(Lum::AspectRatio::Create(control,640,480,true,true));
+    hpanel->AddSpace();
 
-    hpanel->Add(new Lum::HSpace());
-
-    vpanel2=new Lum::VPanel();
-    vpanel2->SetFlex(false,true);
+    vpanel2=Lum::VPanel::Create(false,true);
 
     led=new Lum::LED();
     led->SetModel(knipsing);
     vpanel2->Add(led);
 
-    vpanel2->Add(new Lum::VSpace());
-
-    button=new Lum::Button();
-    button->SetFlex(false,true);
-    button->SetText(L"_Klick!");
-    button->SetType(Lum::Button::typeDefault);
-    button->SetModel(knips);
-    vpanel2->Add(button);
+    vpanel2->AddSpace();
+    vpanel2->Add(Lum::Button::Create(L"_Klick!",knips,Lum::Button::typeDefault,false,true));
 
     hpanel->Add(vpanel2);
 
     vpanel->Add(hpanel);
-
-    vpanel->Add(new Lum::VSpace());
-
-    hpanel=new Lum::HPanel();
-    hpanel->SetFlex(true,false);
-
-    button=new Lum::Button();
-    button->SetText(L"_Prefs");
-    button->SetModel(settings);
-    hpanel->Add(button);
-
-    hpanel->Add(new Lum::HSpace());
-
-    button=new Lum::Button();
-    button->SetText(L"_About");
-    button->SetModel(about);
-    hpanel->Add(button);
-
-    hpanel->Add(new Lum::HSpace());
-
-    text=new Lum::Text();
-    text->SetText(L"Prefix:");
-    hpanel->Add(text);
-
-    hpanel->Add(new Lum::HSpace());
-
-    string=new Lum::String();
-    string->SetFlex(true,false);
-    string->SetModel(imagePrefix);
-    hpanel->Add(string);
-
-    vpanel->Add(hpanel);
+    vpanel->AddSpace();
+    vpanel->Add(Lum::HPanel::Create(true,false)
+                ->Add(Lum::Button::Create(L"_Prefs",settings))
+                ->AddSpace()
+                ->Add(Lum::Button::Create(L"_About",about))
+                ->AddSpace()
+                ->Add(new Lum::Text(L"Prefix:"))
+                ->AddSpace()
+                ->Add(Lum::String::Create(imagePrefix,true,false)));
 
     SetMain(vpanel);
 
